==> nextcloud-17.0.2.tar.bz2: nextcloud/apps/dav/l10n/lt_LT.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalendorius",
    "Todos" : "Užduotys",
    "Personal" : "Asmeniniai",
    "{actor} created calendar {calendar}" : "{actor} sukūrė kalendorių {calendar}",
    "You created calendar {calendar}" : "Jūs sukūrėte kalendorių {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} ištrynė kalendorių {calendar}",
    "You deleted calendar {calendar}" : "Jūs ištrynėte kalendorių {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} atnaujino kalendorių {calendar}",
    "You updated calendar {calendar}" : "Jūs atnaujinote kalendorių {calendar}",
    "You shared calendar {calendar} as public link" : "Jūs pradėjote bendrinti kalendorių {calendar} kaip viešąją nuorodą",
    "You removed public link for calendar {calendar}" : "Jūs pašalinote viešąją nuorodą kalendoriui {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} pradėjo bendrinti su jumis kalendorių {calendar}",
    "You shared calendar {calendar} with {user}" : "Jūs pradėjote bendrinti kalendorių {calendar} su {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} pradėjo bendrinti kalendorių {calendar} su {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} nustojo bendrinti su jumis kalendorių {calendar}",
    "You unshared calendar {calendar} from {user}" : "Jūs nustojote bendrinti kalendorių {calendar} su {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} nustojo bendrinti kalendorių {calendar} su {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} nustojo bendrinti su savimi kalendorių {calendar}",
    "You shared calendar {calendar} with group {group}" : "Jūs pradėjote bendrinti kalendorių {calendar} su grupe {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} pradėjo bendrinti kalendorių {calendar} su grupe {group}",
    "You unshared calendar {calendar} from group {group}" : "Jūs nustojote bendrinti kalendorių {calendar} su grupe {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} nustojo bendrinti kalendorių {calendar} su grupe {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} kalendoriuje {calendar} sukūrė įvykį {event}",
    "You created event {event} in calendar {calendar}" : "Jūs kalendoriuje {calendar} sukūrėte įvykį {event}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} ištrynė įvykį {event} iš kalendoriaus {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Jūs ištrynėte įvykį {event} iš kalendoriaus {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} kalendoriuje {calendar} atnaujino įvykį {event}",
    "You updated event {event} in calendar {calendar}" : "Jūs kalendoriuje {calendar} atnaujinote įvykį {event}",
    "{actor} created todo {todo} in list {calendar}" : "{actor} sąraše {calendar} sukūrė užduotį {todo}",
    "You created todo {todo} in list {calendar}" : "Jūs sąraše {calendar} sukūrėte užduotį {todo}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} iš sąrašo {calendar} ištrynė užduotį {todo}",
    "You deleted todo {todo} from list {calendar}" : "Jūs iš sąrašo {calendar} ištrynėte užduotį {todo}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} sąraše {calendar} atnaujino užduotį {todo}",
    "You updated todo {todo} in list {calendar}" : "Jūs sąraše {calendar} atnaujinote užduotį {todo}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} sąraše {calendar} išsprendė užduotį {todo}",
    "You solved todo {todo} in list {calendar}" : "Jūs sąraše {calendar} išsprendėte užduotį {todo}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} sąraše {calendar} vėl pradėjo užduotį {todo}",
    "You reopened todo {todo} in list {calendar}" : "Jūs sąraše {calendar} vėl pradėjote užduotį {todo}",
    "A <strong>calendar</strong> was modified" : "<strong>Kalendorius</strong> buvo modifikuotas",
    "A calendar <strong>event</strong> was modified" : "Kalendoriaus <strong>įvykis</strong> buvo modifikuotas",
    "A calendar <strong>todo</strong> was modified" : "Kalendoriaus <strong>užduotis</strong> buvo modifikuota",
    "Contact birthdays" : "Adresatų gimtadieniai",
    "Calendar:" : "Kalendorius:",
    "Date:" : "Data:",
    "Where:" : "Kur:",
    "Description:" : "Aprašas:",
    "Untitled event" : "Įvykis be pavadinimo",
    "%s (%s ago)" : "%s (prieš %s)",
    "Calendar: %s" : "Kalendorius: %s",
    "Date: %s" : "Data: %s",
    "Description: %s" : "Aprašas: %s",
    "Where: %s" : "Kur: %s",
    "%1$s via %2$s" : "%1$s per %2$s",
    "Invitation canceled" : "Pakvietimo atsisakyta",
    "Hello %s," : "Sveiki, %s,",
    "The meeting »%1$s« with %2$s was canceled." : "Susikimas „%1$s“ su  %2$s atšauktas.",
    "Invitation updated" : "Pakvietimas atnaujintas",
    "%1$s invited you to »%2$s«" : "%1$s jus pakvietė į »%2$s«",
    "When:" : "Kada:",
    "Link:" : "Nuoroda:",
    "Accept" : "Priimti",
    "Decline" : "Atmesti",
    "More options …" : "Daugiau parinkčių…",
    "Contacts" : "Adresatai",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Norint naudoti CalDAV ir CardDAV su iOS/macOS, jūsų %s turi būti sukonfigūruota taip, kad naudotų HTTPS.",
    "Configures a CalDAV account" : "Konfigūruoja CalDAV paskyrą",
    "Configures a CardDAV account" : "Konfigūruoja CardDAV paskyrą",
    "WebDAV" : "WebDAV",
    "Technical details" : "Techninė informacija",
    "Remote Address: %s" : "Nuotolinis adresas: %s",
    "Request ID: %s" : "Užklausos ID: %s",
    "Are you accepting the invitation?" : "Ar priimate pakvietimą?",
    "Tentative" : "Preliminarus",
    "Save" : "Įrašyti",
    "Calendar server" : "Kalendoriaus serveris",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Taip pat įsidiekite {calendarappstoreopen}Kalendoriaus programėlę{linkclose} arba sinchronizavimui {calendardocopen}prijunkite savo darbalaukį ir mobilųjį ↗{linkclose}.",
    "Send invitations to attendees" : "Siųsti pakvietimus kviestiniams",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Įsitikinkite, kad tinkamai nusistatėte {emailopen}el. pašto serverį{linkclose}.",
    "Automatically generate a birthday calendar" : "Automatiškai sukurti gimtadienių kalendorių",
    "Birthday calendars will be generated by a background job." : "Gimtadienių kalendoriai bus sukurti foninės užduoties.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Tai reiškia, kad jie nebus matomi iš karto įjungus, o pasirodys tik po kurio laiko.",
    "Send notifications for events" : "Siųsti įvykių pranešimus",
    "Please make sure to properly set up the email settings above." : "Įsitikinkite, kad aukščiau tinkamai nusistatėte el. pašto nustatymus.",
    "Notifications will be send through background jobs, so these need to happen often enough." : "Pranešimai bus siunčiami per fonines užduotis, taigi jos turi būti įvykdomos gana dažnai."
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-23.0.0.tar.bz2: nextcloud/apps/dav/l10n/lt_LT.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalendorius",
    "Todos" : "Užduotys",
    "Personal" : "Asmeniniai",
    "{actor} created calendar {calendar}" : "{actor} sukūrė kalendorių {calendar}",
    "You created calendar {calendar}" : "Jūs sukūrėte kalendorių {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} ištrynė kalendorių {calendar}",
    "You deleted calendar {calendar}" : "Jūs ištrynėte kalendorių {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} atnaujino kalendorių {calendar}",
    "You updated calendar {calendar}" : "Jūs atnaujinote kalendorių {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} atkūrė kalendorių {calendar}",
    "You restored calendar {calendar}" : "Jūs atkūrėte kalendorių {calendar}",
    "You shared calendar {calendar} as public link" : "Jūs pradėjote bendrinti kalendorių {calendar} kaip viešąją nuorodą",
    "You removed public link for calendar {calendar}" : "Jūs pašalinote viešąją nuorodą kalendoriui {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} pradėjo bendrinti su jumis kalendorių {calendar}",
    "You shared calendar {calendar} with {user}" : "Jūs pradėjote bendrinti kalendorių {calendar} su {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} pradėjo bendrinti kalendorių {calendar} su {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} nustojo bendrinti su jumis kalendorių {calendar}",
    "You unshared calendar {calendar} from {user}" : "Jūs nustojote bendrinti kalendorių {calendar} su {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} nustojo bendrinti kalendorių {calendar} su {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} nustojo bendrinti su savimi kalendorių {calendar}",
    "You shared calendar {calendar} with group {group}" : "Jūs pradėjote bendrinti kalendorių {calendar} su grupe {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} pradėjo bendrinti kalendorių {calendar} su grupe {group}",
    "You unshared calendar {calendar} from group {group}" : "Jūs nustojote bendrinti kalendorių {calendar} su grupe {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} nustojo bendrinti kalendorių {calendar} su grupe {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} kalendoriuje {calendar} sukūrė įvykį {event}",
    "You created event {event} in calendar {calendar}" : "Jūs kalendoriuje {calendar} sukūrėte įvykį {event}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} ištrynė įvykį {event} iš kalendoriaus {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Jūs ištrynėte įvykį {event} iš kalendoriaus {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} kalendoriuje {calendar} atnaujino įvykį {event}",
    "You updated event {event} in calendar {calendar}" : "Jūs kalendoriuje {calendar} atnaujinote įvykį {event}",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} kalendoriuje {calendar} atkūrė įvykį {event}",
    "You restored event {event} of calendar {calendar}" : "Jūs kalendoriuje {calendar} atkūrėte įvykį {event}",
    "Busy" : "Užimtas laikas",
    "{actor} created todo {todo} in list {calendar}" : "{actor} sąraše {calendar} sukūrė užduotį {todo}",
    "You created todo {todo} in list {calendar}" : "Jūs sąraše {calendar} sukūrėte užduotį {todo}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} iš sąrašo {calendar} ištrynė užduotį {todo}",
    "You deleted todo {todo} from list {calendar}" : "Jūs iš sąrašo {calendar} ištrynėte užduotį {todo}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} sąraše {calendar} atnaujino užduotį {todo}",
    "You updated todo {todo} in list {calendar}" : "Jūs sąraše {calendar} atnaujinote užduotį {todo}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} sąraše {calendar} išsprendė užduotį {todo}",
    "You solved todo {todo} in list {calendar}" : "Jūs sąraše {calendar} išsprendėte užduotį {todo}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} sąraše {calendar} vėl pradėjo užduotį {todo}",
    "You reopened todo {todo} in list {calendar}" : "Jūs sąraše {calendar} vėl pradėjote užduotį {todo}",
    "Calendar, contacts and tasks" : "Kalendorius, adresatai ir užduotys",
    "A <strong>calendar</strong> was modified" : "<strong>Kalendorius</strong> buvo modifikuotas",
    "A calendar <strong>event</strong> was modified" : "Kalendoriaus <strong>įvykis</strong> buvo modifikuotas",
    "A calendar <strong>todo</strong> was modified" : "Kalendoriaus <strong>užduotis</strong> buvo modifikuota",
    "Contact birthdays" : "Adresatų gimtadieniai",
    "Calendar:" : "Kalendorius:",
    "Date:" : "Data:",
    "Where:" : "Kur:",
    "Description:" : "Aprašas:",
    "Untitled event" : "Įvykis be pavadinimo",
    "_%n year_::_%n years_" : ["%n metai","%n metai","%n metų","%n metai"],
    "_%n month_::_%n months_" : ["%n mėnesis","%n mėnesiai","%n mėnesių","%n mėnesis"],
    "_%n day_::_%n days_" : ["%n diena","%n dienos","%n dienų","%n diena"],
    "_%n hour_::_%n hours_" : ["%n valanda","%n valandos","%n valandų","%n valanda"],
    "_%n minute_::_%n minutes_" : ["%n minutė","%n minutės","%n minučių","%n minutė"],
    "%s (in %s)" : "%s (po %s)",
    "%s (%s ago)" : "%s (prieš %s)",
    "Calendar: %s" : "Kalendorius: %s",
    "Date: %s" : "Data: %s",
    "Description: %s" : "Aprašas: %s",
    "Where: %s" : "Kur: %s",
    "%1$s via %2$s" : "%1$s per %2$s",
    "Invitation canceled" : "Pakvietimo atsisakyta",
    "Invitation updated" : "Pakvietimas atnaujintas",
    "Invitation: %1$s" : "Pakvietimas: %1$s",
    "Invitation" : "Pakvietimas",
    "Title:" : "Pavadinimas:",
    "Time:" : "Laikas:",
    "Location:" : "Vieta:",
    "Link:" : "Nuoroda:",
    "Organizer:" : "Organizatorius:",
    "Attendees:" : "Kviestiniai:",
    "Accept" : "Priimti",
    "Decline" : "Atmesti",
    "More options …" : "Daugiau parinkčių…",
    "Contacts" : "Adresatai",
    "{actor} created address book {addressbook}" : "{actor} sukūrė adresų knygą {addressbook}",
    "You created address book {addressbook}" : "Jūs sukūrėte adresų knygą {addressbook}",
    "{actor} deleted address book {addressbook}" : "{actor} ištrynė adresų knygą {addressbook}",
    "You deleted address book {addressbook}" : "Jūs ištrynėte adresų knygą {addressbook}",
    "{actor} updated address book {addressbook}" : "{actor} atnaujino adresų knygą {addressbook}",
    "You updated address book {addressbook}" : "Jūs atnaujinote adresų knygą {addressbook}",
    "System is in maintenance mode." : "Sistema yra techninės priežiūros veiksenoje.",
    "Upgrade needed" : "Reikalingas naujinimas",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Norint naudoti CalDAV ir CardDAV su iOS/macOS, jūsų %s turi būti sukonfigūruota taip, kad naudotų HTTPS.",
    "Configures a CalDAV account" : "Konfigūruoja CalDAV paskyrą",
    "Configures a CardDAV account" : "Konfigūruoja CardDAV paskyrą",
    "Events" : "Įvykiai",
    "Tasks" : "Užduotys",
    "Untitled task" : "Užduotis be pavadinimo",
    "WebDAV" : "WebDAV",
    "Save" : "Įrašyti",
    "Monday" : "Pirmadienis",
    "Tuesday" : "Antradienis",
    "Wednesday" : "Trečiadienis",
    "Thursday" : "Ketvirtadienis",
    "Friday" : "Penktadienis",
    "Saturday" : "Šeštadienis",
    "Sunday" : "Sekmadienis",
    "Calendar server" : "Kalendoriaus serveris",
    "Send invitations to attendees" : "Siųsti pakvietimus kviestiniams",
    "Automatically generate a birthday calendar" : "Automatiškai sukurti gimtadienių kalendorių",
    "Birthday calendars will be generated by a background job." : "Gimtadienių kalendoriai bus sukurti foninės užduoties.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Tai reiškia, kad jie nebus matomi iš karto įjungus, o pasirodys tik po kurio laiko.",
    "Send notifications for events" : "Siųsti įvykių pranešimus",
    "Notifications are sent via background jobs, so these must occur often enough." : "Pranešimai yra siunčiami per fonines užduotis, todėl jos privalo būti vykdomos gana dažnai.",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Taip pat įsidiekite {calendarappstoreopen}Kalendoriaus programėlę{linkclose} arba sinchronizavimui {calendardocopen}prijunkite savo darbalaukį ir mobilųjį ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Įsitikinkite, kad tinkamai nusistatėte {emailopen}el. pašto serverį{linkclose}.",
    "Please contact the organizer directly." : "Prašome susisiekti su organizatoriumi tiesiogiai.",
    "Are you accepting the invitation?" : "Ar priimate pakvietimą?",
    "Tentative" : "Preliminarus",
    "Number of guests" : "Svečių skaičius",
    "Calendar and tasks" : "Kalendorius ir užduotys"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
